@@ -87,27 +87,19 @@ public final class Tagger {
     private ViterbiNode parseImpl(CharSequence text) {
 	final int len = text.length();
 	final ArrayList<ArrayList<ViterbiNode>> nodesAry = new ArrayList<ArrayList<ViterbiNode>>(len+1);
-	final ArrayList<ViterbiNode> perResult = new ArrayList<ViterbiNode>();
 	
 	nodesAry.add(BOS_NODES);
 	for(int i=1; i <= len; i++) 
 	    nodesAry.add(new ArrayList<ViterbiNode>());
 	
-	for(int i=0; i < len; i++, perResult.clear()) {
-	    if(nodesAry.get(i).isEmpty()==false) {
-		wdc.search(text, i, perResult);       // 単語辞書から形態素を検索
-		unk.search(text, i, wdc, perResult);  // 未知語辞書から形態素を検索
-
-		final ArrayList<ViterbiNode> prevs = nodesAry.get(i);
-		for(int j=0; j < perResult.size(); j++) {
-                    final ViterbiNode vn = perResult.get(j);
-		    if(vn.isSpace)
-			nodesAry.get(i+vn.length).addAll(prevs);
-		    else
-			nodesAry.get(i+vn.length).add(setMincostNode(vn,prevs));
-		}
-	    }
-	}
+        MakeLattice fn = new MakeLattice(nodesAry);
+        for(int i=0; i < len; i++) {
+            if(nodesAry.get(i).isEmpty()==false) {
+                fn.set(i);
+                wdc.search(text, i, fn);      // 単語辞書から形態素を検索
+                unk.search(text, i, wdc, fn); // 未知語辞書から形態素を検索
+            }
+        }
 
 	ViterbiNode cur = setMincostNode(ViterbiNode.makeBOSEOS(), nodesAry.get(len)).prev;
 
@@ -124,17 +116,44 @@ public final class Tagger {
 
     private ViterbiNode setMincostNode(ViterbiNode vn, ArrayList<ViterbiNode> prevs) {
 	final ViterbiNode f = vn.prev = prevs.get(0);
-        vn.cost = f.cost + mtx.linkCost(f.rightId, vn.leftId);
+        int minCost = f.cost + mtx.linkCost(f.rightId, vn.leftId);
 
         for(int i=1; i < prevs.size(); i++) {
             final ViterbiNode p = prevs.get(i);
 	    final int cost = p.cost + mtx.linkCost(p.rightId, vn.leftId);
-	    if(cost < vn.cost) {
-		vn.cost = cost;
+	    if(cost < minCost) {
+		minCost = cost;
 		vn.prev = p;
 	    }
 	}
-	vn.cost += wdc.cost(vn.wordId);
+	vn.cost += minCost;
 	return vn;
     }
+
+    private final class MakeLattice implements WordDic.Callback {
+        private final ArrayList<ArrayList<ViterbiNode>> nodesAry;
+        private int i;
+        private ArrayList<ViterbiNode> prevs;
+        private boolean empty=true;
+
+        public MakeLattice(ArrayList<ArrayList<ViterbiNode>> nodesAry) {
+            this.nodesAry = nodesAry;
+        }
+        
+        public void set(int i) {
+            this.i = i;
+            prevs = nodesAry.get(i);
+            empty = true;
+        }
+
+        public void call(ViterbiNode vn) {
+            empty=false;
+            if(vn.isSpace)
+                nodesAry.get(i+vn.length).addAll(prevs);
+            else
+                nodesAry.get(i+vn.length).add(setMincostNode(vn, prevs));
+        }
+        
+        public boolean isEmpty() { return empty; }
+    }
 }
